#########################################

#Machine Learning with R: an introduction

#########################################

#######Data exploratory analysis#########

#text

#packages 
library(tidymodels)
library(tidyverse)
library(ggplot2)

data(mpg)
#View(mpg)
str(mpg)

#Data visualization
ggplot(data = mpg) + 
  geom_point(mapping = aes(x = displ, y = hwy))
ggplot(data = mpg) + 
  geom_point(mapping = aes(x = displ, y = hwy, color = class))
ggplot(data = mpg) + 
  geom_point(mapping = aes(x = displ, y = hwy), color = "blue")

#facet
ggplot(data = mpg) + 
  geom_point(mapping = aes(x = displ, y = hwy)) + 
  facet_wrap(~ class, nrow = 2)
ggplot(data = mpg) + 
  geom_point(mapping = aes(x = displ, y = hwy)) + 
  facet_grid(drv ~ cyl)


# smooth
ggplot(data = mpg) +
  geom_smooth(mapping = aes(x = displ, y = hwy))

ggplot(data = mpg) +
  geom_smooth(mapping = aes(x = displ, y = hwy, group = drv))

ggplot(data = mpg) +
  geom_smooth(
    mapping = aes(x = displ, y = hwy, color = drv),
    show.legend = FALSE
  )

ggplot(data = mpg) + 
  geom_point(mapping = aes(x = displ, y = hwy)) +
  geom_smooth(mapping = aes(x = displ, y = hwy))

ggplot(data = mpg, mapping = aes(x = displ, y = hwy)) + 
  geom_point() + 
  geom_smooth()

ggplot(data = mpg, mapping = aes(x = displ, y = hwy)) + 
  geom_point(mapping = aes(color = class)) + 
  geom_smooth()

##filter
ggplot(data = mpg, mapping = aes(x = displ, y = hwy)) + 
  geom_point(mapping = aes(color = class)) + 
  geom_smooth(data = filter(mpg, class == "subcompact"), se = FALSE)

####histogram
ggplot(data=mpg,aes(hwy))+geom_histogram()
ggplot(data=mpg,aes(hwy,fill=drv))+geom_histogram(bins=10)
ggplot(mpg)+geom_histogram(mapping = aes(x=hwy),color="black",fill="lightblue")+facet_wrap("cyl")

###density plots
ggplot(data = mpg) +
  geom_density(mapping = aes(x = hwy),fill="lightgreen")
ggplot(data = mpg) +
  geom_density(mapping = aes(x = hwy,fill=drv),position="identity")
ggplot(data = mpg) +
  geom_density(mapping = aes(x = hwy,fill=drv),position="stack")

###frequency plots
ggplot(data = mpg, mapping = aes(x = hwy, colour = drv)) +
  geom_freqpoly(binwidth = 1)

###box plot and vioplots
ggplot(data = mpg, aes(hwy)) +  geom_boxplot()
ggplot(data = mpg, aes(class,hwy)) +  geom_boxplot() 
ggplot(data = mpg, aes(class,hwy)) +  geom_boxplot(fill="tomato") 
ggplot(data = mpg, aes(class,hwy)) +  geom_boxplot(fill = "white", colour = "darkgreen") 
ggplot(data = mpg, aes(class,hwy)) +  geom_boxplot(outlier.colour = "red", outlier.shape = 1) 


###ad mean
ggplot(mpg, aes(class, hwy))+geom_boxplot() +
  stat_summary(fun.y=mean, geom="point", shape=20, size=3, color="blue",
               position = position_dodge2(width = 0.75, preserve = "single"))

#vioplots
ggplot(data = mpg) +  geom_violin(aes(class,hwy)) 

#####barchart
ggplot(data = mpg) + 
  geom_bar(mapping = aes(x = class),colour="black",fill="cyan")

ggplot(data = mpg) + 
  geom_bar(mapping = aes(x = class, fill = trans), position = "fill")

ggplot(data = mpg) + 
  geom_bar(mapping = aes(x = class, fill = trans), position = "dodge")

###radar
bar <- ggplot(data = mpg) + 
  geom_bar(
    mapping = aes(x = class, fill = class), 
    show.legend = FALSE,
    width = 1
  ) + 
  theme(aspect.ratio = 1) +
  labs(x = NULL, y = NULL)

bar + coord_flip()
bar + coord_polar()

#heat map
ggplot(data = mpg) + geom_tile(mapping=aes(x=class,y=year,fill=hwy))


#####descriptives
mpg %>%
  summarise(mean = mean(hwy), n = n())

# Usually, you'll want to group first
mpg %>%
  group_by(class) %>%
  summarise(mean = mean(hwy), n = n())

mpg %>%
  group_by(class) %>%
  summarise(mean = mean(hwy), sd = sd(hwy), n = n())

mpg %>%
  group_by(class) %>%
  summarise(mean = mean(hwy), sd = sd(hwy), median = median (hwy), n = n())

descriptives<-mpg %>%
  group_by(class) %>%
  summarise(mean = mean(hwy), sd = sd(hwy), median = median (hwy), n = n())

knitr::kable(descriptives)

library(skimr)
skim(mpg)

####calling functions
elisa_henning <- 16
number<-sqrt(100)
number

###map
it <- map_data("italy")

ggplot(it, aes(long, lat, group = group)) +
  geom_polygon(fill = "white", colour = "black")

ggplot(it, aes(long, lat, group = group)) +
  geom_polygon(fill = "white", colour = "black") +
  coord_quickmap()

