#########################################

#Machine Learning with R: an introduction

#########################################

##############Classification################# 

#load the packages
library(tidyverse)
library(tidymodels)
library(skimr)
library(caret)
library(rpart.plot)

#load the data
data(iris)
?iris
#First six rows
head(iris)
#last six rows
tail(iris)
#the variables 

#Summarize dataset
glimpse(iris)
skim(iris)
iris %>% skim()

#split data
dataset<-iris

validation_index <- createDataPartition(dataset$Species, p=0.80, list=FALSE)
# select 20% of the data for validation
test <- dataset[-validation_index,]
# use the remaining 80% of data to training the models
train <- dataset[validation_index,]

#Now it is time to create some models

control <- trainControl(method="cv", number=10)
metric <- "Accuracy"

#build models

#lda
set.seed(7)
fit.lda <- train(Species~., data=train, method="lda", trControl=control)
fit.lda

#knn
set.seed(7)
fit.knn <- train(Species~., data=train, method="knn", metric=metric, trControl=control)
fit.knn

# SVM
set.seed(7)
fit.svm <- train(Species~., data=train, method="svmRadial", metric=metric, trControl=control)
fit.svm

#decision tree
fit.dt <- train(Species~., data=train, method="rpart", metric=metric, trControl=control)
fit.dt

rpart.plot(fit.dt$finalModel, extra=104)

# Random Forest
set.seed(7)
fit.rf <- train(Species~., data=train, method="rf", metric=metric, trControl=control)
fit.rf

#select best model
# summarize accuracy of models
results <- resamples(list(lda=fit.lda, knn=fit.knn, dt= fit.dt,svm=fit.svm, rf=fit.rf))
summary(results)

# compare accuracy of models
dotplot(results)

# summarize Best Model
print(fit.lda)

#make some predictions
predictions <- predict(fit.lda, test)
confusionMatrix(predictions, test$Species)






