#########################################

#Machine Learning with R: an introduction

#########################################

##############Regression################# 

#load the packages
library(tidyverse)
library(tidymodels)
library(skimr)
library(caret)
library(broom)
library(ggplot2)
library(MASS)
library(rpart.plot)

#load the data
data("Boston")
?Boston
#First six rows
head(Boston)
#last six rows
tail(Boston)
#the variables 

#Summarize dataset
glimpse(Boston)
skim(Boston)
Boston %>% summarise(mean = mean(medv),sd = sd (medv),n=n())

#regression

#split data
#Now it is time to create some models

validation_index <- createDataPartition(Boston$medv, p=0.80, list=FALSE)
# select 20% of the data for validation
test <- Boston[-validation_index,]
# use the remaining 80% of data to training the models
train <- Boston[validation_index,]

control <- trainControl(method="cv", number=10)

#build models

#llinear regression
set.seed(7)
fit.lm <- train(medv~., data=train, method="lm", trControl=control)
fit.lm
summary(fit.lm)

#knn
set.seed(7)
fit.knn <- train(medv~., data=train, method="knn", trControl=control)
fit.knn

#decision tree
fit.dt <- train(medv~., data=train, method="rpart", trControl=control)
fit.dt

#plot
rpart.plot(fit.dt$finalModel)

# Random Forest
set.seed(7)
fit.rf <- train(medv~., data=train, method="rf", trControl=control)
fit.rf

varImp(fit.rf)
plot(varImp(fit.rf))

#select best model
# summarize accuracy of models
results <- resamples(list(lm=fit.lm, knn=fit.knn, dt= fit.dt, rf=fit.rf))
summary(results)

# summarize Best Model
print(fit.rf)
fit.rf$results

#make some predictions
predictions <- predict(fit.rf, test)
postResample(pred=predictions,obs=test$medv)
ggplot(test)+geom_point(aes(x=test$medv,y=predictions))





